@@ -2,6 +2,11 @@ from PyObjCTools.TestSupport import *
 
 from Foundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestNSHTTPCookie (TestCase):
     def testConstants(self):
         self.assertIsInstance(NSHTTPCookieName, unicode)
@@ -17,6 +22,7 @@ class TestNSHTTPCookie (TestCase):
         self.assertIsInstance(NSHTTPCookieDiscard, unicode)
         self.assertIsInstance(NSHTTPCookieMaximumAge, unicode)
         self.assertIsInstance(NSHTTPCookiePort, unicode)
+
     def testMethods(self):
         self.assertResultIsBOOL(NSHTTPCookie.isSessionOnly)
         self.assertResultIsBOOL(NSHTTPCookie.isSecure)
