@@ -12,6 +12,9 @@ class TestNSXMLNodeOptions (TestCase):
         self.assertEqual(NSXMLDocumentTidyHTML, 1 << 9)
         self.assertEqual(NSXMLDocumentTidyXML, 1 << 10)
         self.assertEqual(NSXMLDocumentValidate, 1 << 13)
+        self.assertEqual(NSXMLNodeLoadExternalEntitiesAlways, 1 << 14)
+        self.assertEqual(NSXMLNodeLoadExternalEntitiesSameOriginOnly, 1 << 15)
+        self.assertEqual(NSXMLNodeLoadExternalEntitiesNever, 1 << 19)
         self.assertEqual(NSXMLDocumentXInclude, 1 << 16)
         self.assertEqual(NSXMLNodePrettyPrint, 1 << 17)
         self.assertEqual(NSXMLDocumentIncludeContentTypeDeclaration, 1 << 18)
